@@ -60,6 +60,7 @@ pub trait NumberInstance:
     type Abs: NumberInstance;
     type Exp: NumberInstance;
     type Log: NumberInstance;
+    type Round: NumberInstance;
     type Class: NumberClass<Instance = Self>;
 
     /// Get an impl of [`NumberClass`] describing this number.
@@ -118,6 +119,9 @@ pub trait NumberInstance:
         this.or(that).into()
     }
 
+    /// Return this number rounded to the nearest integer.
+    fn round(self) -> Self::Round;
+
     /// Return `true` if exactly one of `self` and `other` is zero.
     fn xor(self, other: Self) -> Self
     where
