@@ -32,6 +32,7 @@ impl NumberInstance for Boolean {
     type Abs = Self;
     type Exp = Float;
     type Log = Float;
+    type Round = Self;
     type Class = BooleanType;
 
     fn class(&self) -> BooleanType {
@@ -81,6 +82,10 @@ impl NumberInstance for Boolean {
         Self(self.0 || other.0)
     }
 
+    fn round(self) -> Self::Round {
+        self
+    }
+
     fn xor(self, other: Self) -> Self {
         Self(self.0 ^ other.0)
     }
@@ -268,6 +273,7 @@ impl NumberInstance for Complex {
     type Abs = Float;
     type Exp = Self;
     type Log = Self;
+    type Round = Self;
     type Class = ComplexType;
 
     fn class(&self) -> ComplexType {
@@ -342,6 +348,13 @@ impl NumberInstance for Complex {
             },
         }
     }
+
+    fn round(self) -> Self::Round {
+        match self {
+            Self::C32(c) => Self::C32(_Complex::new(c.re.round(), c.im.round())),
+            Self::C64(c) => Self::C64(_Complex::new(c.re.round(), c.im.round())),
+        }
+    }
 }
 
 impl FloatInstance for Complex {
@@ -726,6 +739,7 @@ impl NumberInstance for Float {
     type Abs = Float;
     type Exp = Self;
     type Log = Self;
+    type Round = Int;
     type Class = FloatType;
 
     fn class(&self) -> FloatType {
@@ -794,6 +808,13 @@ impl NumberInstance for Float {
             },
         }
     }
+
+    fn round(self) -> Self::Round {
+        match self {
+            Self::F32(f) => (f.round() as i32).into(),
+            Self::F64(f) => (f.round() as i64).into(),
+        }
+    }
 }
 
 impl RealInstance for Float {
@@ -1160,6 +1181,7 @@ impl NumberInstance for Int {
     type Abs = Self;
     type Exp = Float;
     type Log = Float;
+    type Round = Self;
     type Class = IntType;
 
     fn class(&self) -> IntType {
@@ -1239,6 +1261,10 @@ impl NumberInstance for Int {
             Self::I64(this) => Self::I64(this.pow(exp.cast_into())),
         }
     }
+
+    fn round(self) -> Self::Round {
+        self
+    }
 }
 
 impl RealInstance for Int {
@@ -1640,6 +1666,7 @@ impl NumberInstance for UInt {
     type Abs = Self;
     type Exp = Float;
     type Log = Float;
+    type Round = Self;
     type Class = UIntType;
 
     fn class(&self) -> UIntType {
@@ -1714,6 +1741,10 @@ impl NumberInstance for UInt {
             Self::U64(this) => Self::U64(this.pow(exp.cast_into())),
         }
     }
+
+    fn round(self) -> Self::Round {
+        self
+    }
 }
 
 impl RealInstance for UInt {
