@@ -953,6 +953,16 @@ impl fmt::Display for Number {
 mod tests {
     use super::*;
 
+    #[test]
+    fn test_log() {
+        let n = 1.23f32;
+        assert_eq!(n.ln(), Number::from(n).ln().cast_into());
+        assert_eq!(
+            (-n).ln().is_nan(),
+            f32::cast_from(Number::from(-n).ln()).is_nan()
+        );
+    }
+
     #[test]
     fn test_ops() {
         let ones = [
